@@ -3,10 +3,30 @@ package MooseX::WithCache;
 use MooseX::Role::Parameterized;
 use 5.008;
 use constant DEBUG => $ENV{MOOSEX_WITHCACHE_DEBUG} ? 1 : 0;
-our $VERSION   = '0.00999_03';
+our $VERSION   = '0.00999_04';
 our $AUTHORITY = 'cpan:DMAKI';
 my %BACKENDS;
 
+# This is solely for backwards compatibility
+use Moose::Exporter;
+Moose::Exporter->setup_import_methods(
+    with_caler => [ 'with_cache' ],
+);
+
+sub with_cache {
+    my ($caller, $name, %args) = @_;
+
+    Carp::carp("use of with_cache for MooseX::WithCache is now deprecated. Use parameterized roles directly");
+
+    Moose::Util::apply_all_roles(
+        $caller,
+        __PACKAGE__, {
+            %args,
+            name => $name,
+        }
+    );
+}
+
 parameter backend => (
     isa => 'Str',
     required => 1,
